class ApplicationController < ActionController::Base
  protect_from_forgery

  before_filter :secure_facebook_session

  helper_method :connected?, :facebook_user

  private

  def require_connected_user
    respond_to do |format|
      format.html { redirect_to(root_path) }
      format.js { head(:forbidden) }
    end unless connected?
  end

  def connected?
    !!facebook_user
  end

  def facebook_user
    facebook_session.user if facebook_session.secured?
  end

  def facebook_session
    @facebook_session ||= Facebooker::Session.new
  end

  def secure_facebook_session
    values = facebook_session_cookies
    facebook_session.secure_with!(*values) if values.length == 4
  end

  def facebook_session_cookies
    %w(session_key user expires ss).map { |name| cookies["#{Cyty::Facebook.api_key}_#{name}"]}.compact
  end
end
