require 'uri'

class Quotation < ActiveRecord::Base
  PUBLICATION_THRESHOLD = 1
  
  has_many :votes

  attr_accessible :body, :author, :source

  validates :body,   :presence => true, :length => {:maximum => 1000}, :uniqueness => {:scope => :author}
  validates :author, :presence => true, :length => {:maximum => 50}
  validates :source, :presence => true, :length => {:maximum => 100}

  after_create :vote_as_submitter

  scope :latest, order('created_at DESC')
  scope :top, order('votes_count DESC')
  scope :with_votes, includes(:votes)
  scope :published, where('published_at IS NOT NULL')
  scope :submitted_by, lambda { |uid| where(:uid => uid) }
  scope :voted_by, lambda { |uid| joins(:votes).where(['votes.uid = quotations.uid AND quotations.uid = ?', uid]) }

  self.per_page = 15
  
  def source_url
    source.starts_with?('http://') ? source : "http://www.google.pl/search?q=#{URI.escape(source)}"
  end
  
  def publishable?
    votes_to_publish < 1
  end
  
  def votes_to_publish
    PUBLICATION_THRESHOLD - votes.count
  end
  
  def publish
    update_attribute(:published_at, Time.now)
  end
  
  private
  
  def vote_as_submitter
    votes.create(:uid => uid)
  end
end
